# This script automates the process of taking files from Nisus Writer's sandbox and
# restoring them to the older (unsandboxed) locations.
#
use strict;

my $home = $ENV{HOME};
my $appSupportFolderName = "Nisus Writer Pro";
my $sandboxRootFolder = "$home/Library/Containers/com.nisus.NisusWriter";
my $sandbox = "$sandboxRootFolder/Data";

my $prefsFileName = "com.nisus.NisusWriter.plist";
my $docman = "$home/Documents/Nisus Documents";

if( ! -e $sandboxRootFolder ) {
	die "The Nisus Writer Pro sandbox container does not appear to exist.\nExpected location: $sandboxRootFolder\n";
}


### ask the user about their Document Manager folder
print "This script will revert your sandboxed data. \n";
print "It is necessary to move some files from your sandboxed Document Manager location to the Application Support folder. \n";

if( -e $docman ) {
	print "Is your document manager folder located at:\n\t$docman\n\t(please enter 'yes' or 'no')\n";
	my $answer = "";
	chomp ($answer = <STDIN>);
	if( 'yes' ne $answer ) {
		$docman = '';
	}
}
else {
	$docman = '';
}

while( ! -e $docman ) {
	print "Please enter the full path to your Document Manager folder:\n";
	chomp ($docman = <STDIN>);
}





### create a folder for files we will be replacing, so user has access if they made a mistake
my $base = "$home/Desktop/Nisus Unsandbox Moved Aside";
my $backup = $base;

my $suffix = 2;
while( -e $backup ) {
	$backup = "$base $suffix";
	$suffix++;
}

mkdir $backup;
print "...\n\n";



### have OSX use the preferences from inside the sandbox
my $prefsPath = "$sandbox/Library/Preferences/$prefsFileName";
if( -e $prefsPath ) {
	`defaults import "com.nisus.NisusWriter" "$prefsPath"`;
	print "Restored preferences from $prefsPath \n";
}
else {
	print "WARNING: missing sandboxed preferences from: $prefsPath \n";
}



### move items from inside the sandbox to outside
sub moveItemFromSandbox
{
	my $folderName = shift;
	my $itemName = shift;
	my $itemPathFrag = "$folderName/$itemName";
	
	my $outside = "$home/Library/$itemPathFrag";
	my $inside = "$sandbox/Library/$itemPathFrag";
	
	# move aside existing file at destination to rescue folder
	if( -e $outside ) {
		mkdir "$backup/$folderName";
		`mv "$outside" "$backup/$itemPathFrag"`;
	}
	
	# move sandboxed item to the destination
	if( -e $inside ) {
		`mv "$inside" "$outside"`;
		print "Moved outside the sandbox: $itemPathFrag \n";
	}
	else {
		print "WARNING: expected item at location: $inside \n";
	}
	
}

moveItemFromSandbox( "Application Support", $appSupportFolderName );
moveItemFromSandbox( "Preferences", $prefsFileName );


### move items from the Doc Man folder to App Support
sub moveItemFromDocMan
{
	my $itemName = shift;
	
	my $source = "$docman/$itemName";
	my $dest = "$home/Library/Application Support/$appSupportFolderName/$itemName";
	
	if( ! -e $source ) {
		print "No $itemName detected inside Document Manager \n";
		return; # nothing to move	
	}
	
	# move the item from the App Support to the recue folder
	if( -e $dest ) {
		`mv "$dest" "$backup/$itemName"`;
	}
	
	`mv "$source" "$dest"`;
	print "Restored from Document Manager: $itemName \n";
}

moveItemFromDocMan( "Macros" );
moveItemFromDocMan( "Glossaries" );
moveItemFromDocMan( "Templates" );
moveItemFromDocMan( "Style Library" );


### remove the sandbox container folder
`mv "$sandboxRootFolder" "$backup/com.nisus.NisusWriter"`;



# done
print "\n\n";
print "Conversion complete. You may now launch the older version of Nisus Writer Pro. \n";
print "You may need to reselect your Document Manager folder location in the preferences. \n";

